Python: module pydbproperties

pydbproperties |

`author: José Roberto Meza Cabrera
mail: robertpro01@gmail.com
With this script, you can use store properties into a
MySQL table, you can change the name of the table, and
list the properties into a output stream or file
stream, etc.`

Modules
`` |  |
myquerybuilder | re | sys |

Classes
`` |  | pydbproperties
class pydbproperties
`` | `A Python implements of pyjavaproperties for database`
| Methods defined here: __getitem__(self, name) `To support direct dictionary like access` __init__(self) __setitem__(self, name, value) `To support direct dictionary like access` conn(self, **kwargs) `Instance a connection with the database` create_table(self) `Create a table, if you don't use set_table_name() method, the name of the table will be default( pydbproperties )` escape(self, value) get_property(self, key) `Return a property for the given key` get_property_dict(self) `Returns property dict` get_property_names(self) `Return an iterator over all the keys of the property dictionary, i.e the names of the properties` get_table_name(self) `Returns table name` list(self, out=<open file '<stdout>', mode 'w'>) `Prints a listing of the properties to the stream 'out' which defaults to the standard output` load(self) `Load properties from database` process_pair(self, key, value) `Process a (key, value) pair` remove_property(self, property) `Remove a property if property is None: remove all properties` remove_property_db(self, prop) `Remove a property directly from a database if property is None: remove all properties directly from a database` set_auto_load(self, boolean) `Set True for working directly with the database` set_auto_store(self, boolean) `Set True for working directly with the database` set_property(self, key, value) `Set the property for the given key` set_table_name(self, table_name) `Sets table name` store(self) `Stores the dict to a database` unescape(self, value)

Data
`` |  | NULL = ('', None, (), [], {}) print_function = _Feature((2, 6, 0, 'alpha', 2), (3, 0, 0, 'alpha', 0), 65536)